# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from picteus_ws_client.models.manifest_capability import ManifestCapability
from picteus_ws_client.models.manifest_event import ManifestEvent
from picteus_ws_client.models.manifest_execution import ManifestExecution
from picteus_ws_client.models.manifest_extension_command import ManifestExtensionCommand
from picteus_ws_client.models.manifest_throttling_policy import ManifestThrottlingPolicy
from typing import Optional, Set
from typing_extensions import Self

class ManifestInstructions(BaseModel):
    """
    The full specifications of an extension, including the events it handles, its capabilities, its execution and its commands
    """ # noqa: E501
    events: Annotated[List[ManifestEvent], Field(min_length=1)] = Field(description="The events which will trigger the instructions")
    capabilities: Optional[List[ManifestCapability]] = Field(default=None, description="The capabilities attached to the instructions")
    throttling_policies: Optional[List[ManifestThrottlingPolicy]] = Field(default=None, description="The throttling policies for some events", alias="throttlingPolicies")
    execution: ManifestExecution = Field(description="The execution to run when one of the event of the instructions occurs")
    commands: Optional[List[ManifestExtensionCommand]] = Field(default=None, description="The possible commands of the event")
    __properties: ClassVar[List[str]] = ["events", "capabilities", "throttlingPolicies", "execution", "commands"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ManifestInstructions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in capabilities (list)
        _items = []
        if self.capabilities:
            for _item_capabilities in self.capabilities:
                if _item_capabilities:
                    _items.append(_item_capabilities.to_dict())
            _dict['capabilities'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in throttling_policies (list)
        _items = []
        if self.throttling_policies:
            for _item_throttling_policies in self.throttling_policies:
                if _item_throttling_policies:
                    _items.append(_item_throttling_policies.to_dict())
            _dict['throttlingPolicies'] = _items
        # override the default output from pydantic by calling `to_dict()` of execution
        if self.execution:
            _dict['execution'] = self.execution.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in commands (list)
        _items = []
        if self.commands:
            for _item_commands in self.commands:
                if _item_commands:
                    _items.append(_item_commands.to_dict())
            _dict['commands'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ManifestInstructions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "events": obj.get("events"),
            "capabilities": [ManifestCapability.from_dict(_item) for _item in obj["capabilities"]] if obj.get("capabilities") is not None else None,
            "throttlingPolicies": [ManifestThrottlingPolicy.from_dict(_item) for _item in obj["throttlingPolicies"]] if obj.get("throttlingPolicies") is not None else None,
            "execution": ManifestExecution.from_dict(obj["execution"]) if obj.get("execution") is not None else None,
            "commands": [ManifestExtensionCommand.from_dict(_item) for _item in obj["commands"]] if obj.get("commands") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from picteus_ws_client.models.search_property_range import SearchPropertyRange
from typing import Optional, Set
from typing_extensions import Self

class SearchProperties(BaseModel):
    """
    Technical properties to match when searching for images, i.e. how an image search should operate regarding the image technical properties
    """ # noqa: E501
    width: Optional[SearchPropertyRange] = Field(default=None, description="The range of the image width")
    height: Optional[SearchPropertyRange] = Field(default=None, description="The range of the image height")
    weight_in_bytes: Optional[SearchPropertyRange] = Field(default=None, description="The range of the image binary weight", alias="weightInBytes")
    creation_date: Optional[SearchPropertyRange] = Field(default=None, description="The range of the image creation dates, expressed in milliseconds from 1970, January 1st", alias="creationDate")
    modification_date: Optional[SearchPropertyRange] = Field(default=None, description="The range of the image modification dates, expressed in milliseconds from 1970, January 1st", alias="modificationDate")
    __properties: ClassVar[List[str]] = ["width", "height", "weightInBytes", "creationDate", "modificationDate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SearchProperties from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of width
        if self.width:
            _dict['width'] = self.width.to_dict()
        # override the default output from pydantic by calling `to_dict()` of height
        if self.height:
            _dict['height'] = self.height.to_dict()
        # override the default output from pydantic by calling `to_dict()` of weight_in_bytes
        if self.weight_in_bytes:
            _dict['weightInBytes'] = self.weight_in_bytes.to_dict()
        # override the default output from pydantic by calling `to_dict()` of creation_date
        if self.creation_date:
            _dict['creationDate'] = self.creation_date.to_dict()
        # override the default output from pydantic by calling `to_dict()` of modification_date
        if self.modification_date:
            _dict['modificationDate'] = self.modification_date.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SearchProperties from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "width": SearchPropertyRange.from_dict(obj["width"]) if obj.get("width") is not None else None,
            "height": SearchPropertyRange.from_dict(obj["height"]) if obj.get("height") is not None else None,
            "weightInBytes": SearchPropertyRange.from_dict(obj["weightInBytes"]) if obj.get("weightInBytes") is not None else None,
            "creationDate": SearchPropertyRange.from_dict(obj["creationDate"]) if obj.get("creationDate") is not None else None,
            "modificationDate": SearchPropertyRange.from_dict(obj["modificationDate"]) if obj.get("modificationDate") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.search_criteria import SearchCriteria

class TestSearchCriteria(unittest.TestCase):
    """SearchCriteria unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchCriteria:
        """Test SearchCriteria
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchCriteria`
        """
        model = SearchCriteria()
        if include_optional:
            return SearchCriteria(
                formats = [PNG, JPEG],
                keyword = picteus_ws_client.models.search_keyword.SearchKeyword(
                    text = 'comfy', 
                    in_name = True, 
                    in_metadata = True, 
                    in_features = True, ),
                tags = picteus_ws_client.models.search_tags.SearchTags(
                    values = [nature], ),
                features = picteus_ws_client.models.search_features.SearchFeatures(
                    operator = or, 
                    conditions = [
                        picteus_ws_client.models.search_feature_condition.SearchFeatureCondition(
                            type = nature, 
                            format = null, 
                            name = 'field', 
                            operator = null, 
                            value = Three women in a flower arrangement, )
                        ], 
                    features = null, ),
                properties = picteus_ws_client.models.search_properties.SearchProperties(
                    width = null, 
                    height = null, 
                    weight_in_bytes = null, 
                    creation_date = null, 
                    modification_date = null, )
            )
        else:
            return SearchCriteria(
        )
        """

    def testSearchCriteria(self):
        """Test SearchCriteria"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from picteus_ws_client.api.administration_api import AdministrationApi
from picteus_ws_client.api.api_secret_api import ApiSecretApi
from picteus_ws_client.api.collection_api import CollectionApi
from picteus_ws_client.api.extension_api import ExtensionApi
from picteus_ws_client.api.image_api import ImageApi
from picteus_ws_client.api.image_attachment_api import ImageAttachmentApi
from picteus_ws_client.api.miscellaneous_api import MiscellaneousApi
from picteus_ws_client.api.repository_api import RepositoryApi
from picteus_ws_client.api.settings_api import SettingsApi




# coding: utf-8

# flake8: noqa

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.12.0"

# Define package exports
__all__ = [
    "AdministrationApi",
    "ApiSecretApi",
    "CollectionApi",
    "ExtensionApi",
    "ImageApi",
    "ImageAttachmentApi",
    "MiscellaneousApi",
    "RepositoryApi",
    "SettingsApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ApiSecret",
    "ApiSecretSummary",
    "ApiSecretType",
    "ApplicationMetadata",
    "ApplicationMetadataItem",
    "ApplicationMetadataItemValue",
    "Collection",
    "CommandEntity",
    "ComputedImageFormat",
    "ConfigurationCapability",
    "ConfigurationExtensionCommand",
    "ConstantsRegistry",
    "Dates",
    "Extension",
    "ExtensionActivity",
    "ExtensionActivityKind",
    "ExtensionAndManual",
    "ExtensionGenerationOptions",
    "ExtensionImageEmbeddings",
    "ExtensionImageFeature",
    "ExtensionImageFeatureName",
    "ExtensionImageFeaturesAttribute",
    "ExtensionImageTag",
    "ExtensionImageTagsAttribute",
    "ExtensionManual",
    "ExtensionSettings",
    "ExtensionStatus",
    "ExtensionsConfiguration",
    "GenerationRecipe",
    "GenerationRecipePrompt",
    "Image",
    "ImageDimensions",
    "ImageDistance",
    "ImageEmbeddings",
    "ImageFeature",
    "ImageFeatureFormat",
    "ImageFeatureNullValue",
    "ImageFeatureType",
    "ImageFeatureValue",
    "ImageFormat",
    "ImageMediaUrl",
    "ImageMetadata",
    "ImageResizeRender",
    "ImageSummary",
    "InstructionsPrompt",
    "Manifest",
    "ManifestCapability",
    "ManifestCapabilityId",
    "ManifestEvent",
    "ManifestExecution",
    "ManifestExtensionCommand",
    "ManifestExtensionCommandOn",
    "ManifestExtensionCommandSpecification",
    "ManifestInstructions",
    "ManifestInterfaceElement",
    "ManifestRuntime",
    "ManifestRuntimeEnvironment",
    "ManifestThrottlingPolicy",
    "ManifestUserInterface",
    "PromptKind",
    "Repository",
    "RepositoryActivity",
    "RepositoryActivityKind",
    "RepositoryLocationType",
    "RepositoryStatus",
    "SearchCriteria",
    "SearchFeatureComparisonOperator",
    "SearchFeatureCondition",
    "SearchFeatureConditionValue",
    "SearchFeatureLogicalOperator",
    "SearchFeatures",
    "SearchFeaturesResult",
    "SearchFilter",
    "SearchFilterOrigin",
    "SearchImageResult",
    "SearchImageSummaryResult",
    "SearchImagesOrigin",
    "SearchKeyword",
    "SearchMediaUrlResult",
    "SearchOriginNature",
    "SearchParameters",
    "SearchProperties",
    "SearchPropertyRange",
    "SearchRange",
    "SearchRepositoriesOrigin",
    "SearchSorting",
    "SearchSortingProperty",
    "SearchTags",
    "SearchTagsResult",
    "Settings",
    "Software",
    "TextualPrompt",
    "UserInterfaceAnchor",
]

# import apis into sdk package
from picteus_ws_client.api.administration_api import AdministrationApi as AdministrationApi
from picteus_ws_client.api.api_secret_api import ApiSecretApi as ApiSecretApi
from picteus_ws_client.api.collection_api import CollectionApi as CollectionApi
from picteus_ws_client.api.extension_api import ExtensionApi as ExtensionApi
from picteus_ws_client.api.image_api import ImageApi as ImageApi
from picteus_ws_client.api.image_attachment_api import ImageAttachmentApi as ImageAttachmentApi
from picteus_ws_client.api.miscellaneous_api import MiscellaneousApi as MiscellaneousApi
from picteus_ws_client.api.repository_api import RepositoryApi as RepositoryApi
from picteus_ws_client.api.settings_api import SettingsApi as SettingsApi

# import ApiClient
from picteus_ws_client.api_response import ApiResponse as ApiResponse
from picteus_ws_client.api_client import ApiClient as ApiClient
from picteus_ws_client.configuration import Configuration as Configuration
from picteus_ws_client.exceptions import OpenApiException as OpenApiException
from picteus_ws_client.exceptions import ApiTypeError as ApiTypeError
from picteus_ws_client.exceptions import ApiValueError as ApiValueError
from picteus_ws_client.exceptions import ApiKeyError as ApiKeyError
from picteus_ws_client.exceptions import ApiAttributeError as ApiAttributeError
from picteus_ws_client.exceptions import ApiException as ApiException

# import models into sdk package
from picteus_ws_client.models.api_secret import ApiSecret as ApiSecret
from picteus_ws_client.models.api_secret_summary import ApiSecretSummary as ApiSecretSummary
from picteus_ws_client.models.api_secret_type import ApiSecretType as ApiSecretType
from picteus_ws_client.models.application_metadata import ApplicationMetadata as ApplicationMetadata
from picteus_ws_client.models.application_metadata_item import ApplicationMetadataItem as ApplicationMetadataItem
from picteus_ws_client.models.application_metadata_item_value import ApplicationMetadataItemValue as ApplicationMetadataItemValue
from picteus_ws_client.models.collection import Collection as Collection
from picteus_ws_client.models.command_entity import CommandEntity as CommandEntity
from picteus_ws_client.models.computed_image_format import ComputedImageFormat as ComputedImageFormat
from picteus_ws_client.models.configuration_capability import ConfigurationCapability as ConfigurationCapability
from picteus_ws_client.models.configuration_extension_command import ConfigurationExtensionCommand as ConfigurationExtensionCommand
from picteus_ws_client.models.constants_registry import ConstantsRegistry as ConstantsRegistry
from picteus_ws_client.models.dates import Dates as Dates
from picteus_ws_client.models.extension import Extension as Extension
from picteus_ws_client.models.extension_activity import ExtensionActivity as ExtensionActivity
from picteus_ws_client.models.extension_activity_kind import ExtensionActivityKind as ExtensionActivityKind
from picteus_ws_client.models.extension_and_manual import ExtensionAndManual as ExtensionAndManual
from picteus_ws_client.models.extension_generation_options import ExtensionGenerationOptions as ExtensionGenerationOptions
from picteus_ws_client.models.extension_image_embeddings import ExtensionImageEmbeddings as ExtensionImageEmbeddings
from picteus_ws_client.models.extension_image_feature import ExtensionImageFeature as ExtensionImageFeature
from picteus_ws_client.models.extension_image_feature_name import ExtensionImageFeatureName as ExtensionImageFeatureName
from picteus_ws_client.models.extension_image_features_attribute import ExtensionImageFeaturesAttribute as ExtensionImageFeaturesAttribute
from picteus_ws_client.models.extension_image_tag import ExtensionImageTag as ExtensionImageTag
from picteus_ws_client.models.extension_image_tags_attribute import ExtensionImageTagsAttribute as ExtensionImageTagsAttribute
from picteus_ws_client.models.extension_manual import ExtensionManual as ExtensionManual
from picteus_ws_client.models.extension_settings import ExtensionSettings as ExtensionSettings
from picteus_ws_client.models.extension_status import ExtensionStatus as ExtensionStatus
from picteus_ws_client.models.extensions_configuration import ExtensionsConfiguration as ExtensionsConfiguration
from picteus_ws_client.models.generation_recipe import GenerationRecipe as GenerationRecipe
from picteus_ws_client.models.generation_recipe_prompt import GenerationRecipePrompt as GenerationRecipePrompt
from picteus_ws_client.models.image import Image as Image
from picteus_ws_client.models.image_dimensions import ImageDimensions as ImageDimensions
from picteus_ws_client.models.image_distance import ImageDistance as ImageDistance
from picteus_ws_client.models.image_embeddings import ImageEmbeddings as ImageEmbeddings
from picteus_ws_client.models.image_feature import ImageFeature as ImageFeature
from picteus_ws_client.models.image_feature_format import ImageFeatureFormat as ImageFeatureFormat
from picteus_ws_client.models.image_feature_null_value import ImageFeatureNullValue as ImageFeatureNullValue
from picteus_ws_client.models.image_feature_type import ImageFeatureType as ImageFeatureType
from picteus_ws_client.models.image_feature_value import ImageFeatureValue as ImageFeatureValue
from picteus_ws_client.models.image_format import ImageFormat as ImageFormat
from picteus_ws_client.models.image_media_url import ImageMediaUrl as ImageMediaUrl
from picteus_ws_client.models.image_metadata import ImageMetadata as ImageMetadata
from picteus_ws_client.models.image_resize_render import ImageResizeRender as ImageResizeRender
from picteus_ws_client.models.image_summary import ImageSummary as ImageSummary
from picteus_ws_client.models.instructions_prompt import InstructionsPrompt as InstructionsPrompt
from picteus_ws_client.models.manifest import Manifest as Manifest
from picteus_ws_client.models.manifest_capability import ManifestCapability as ManifestCapability
from picteus_ws_client.models.manifest_capability_id import ManifestCapabilityId as ManifestCapabilityId
from picteus_ws_client.models.manifest_event import ManifestEvent as ManifestEvent
from picteus_ws_client.models.manifest_execution import ManifestExecution as ManifestExecution
from picteus_ws_client.models.manifest_extension_command import ManifestExtensionCommand as ManifestExtensionCommand
from picteus_ws_client.models.manifest_extension_command_on import ManifestExtensionCommandOn as ManifestExtensionCommandOn
from picteus_ws_client.models.manifest_extension_command_specification import ManifestExtensionCommandSpecification as ManifestExtensionCommandSpecification
from picteus_ws_client.models.manifest_instructions import ManifestInstructions as ManifestInstructions
from picteus_ws_client.models.manifest_interface_element import ManifestInterfaceElement as ManifestInterfaceElement
from picteus_ws_client.models.manifest_runtime import ManifestRuntime as ManifestRuntime
from picteus_ws_client.models.manifest_runtime_environment import ManifestRuntimeEnvironment as ManifestRuntimeEnvironment
from picteus_ws_client.models.manifest_throttling_policy import ManifestThrottlingPolicy as ManifestThrottlingPolicy
from picteus_ws_client.models.manifest_user_interface import ManifestUserInterface as ManifestUserInterface
from picteus_ws_client.models.prompt_kind import PromptKind as PromptKind
from picteus_ws_client.models.repository import Repository as Repository
from picteus_ws_client.models.repository_activity import RepositoryActivity as RepositoryActivity
from picteus_ws_client.models.repository_activity_kind import RepositoryActivityKind as RepositoryActivityKind
from picteus_ws_client.models.repository_location_type import RepositoryLocationType as RepositoryLocationType
from picteus_ws_client.models.repository_status import RepositoryStatus as RepositoryStatus
from picteus_ws_client.models.search_criteria import SearchCriteria as SearchCriteria
from picteus_ws_client.models.search_feature_comparison_operator import SearchFeatureComparisonOperator as SearchFeatureComparisonOperator
from picteus_ws_client.models.search_feature_condition import SearchFeatureCondition as SearchFeatureCondition
from picteus_ws_client.models.search_feature_condition_value import SearchFeatureConditionValue as SearchFeatureConditionValue
from picteus_ws_client.models.search_feature_logical_operator import SearchFeatureLogicalOperator as SearchFeatureLogicalOperator
from picteus_ws_client.models.search_features import SearchFeatures as SearchFeatures
from picteus_ws_client.models.search_features_result import SearchFeaturesResult as SearchFeaturesResult
from picteus_ws_client.models.search_filter import SearchFilter as SearchFilter
from picteus_ws_client.models.search_filter_origin import SearchFilterOrigin as SearchFilterOrigin
from picteus_ws_client.models.search_image_result import SearchImageResult as SearchImageResult
from picteus_ws_client.models.search_image_summary_result import SearchImageSummaryResult as SearchImageSummaryResult
from picteus_ws_client.models.search_images_origin import SearchImagesOrigin as SearchImagesOrigin
from picteus_ws_client.models.search_keyword import SearchKeyword as SearchKeyword
from picteus_ws_client.models.search_media_url_result import SearchMediaUrlResult as SearchMediaUrlResult
from picteus_ws_client.models.search_origin_nature import SearchOriginNature as SearchOriginNature
from picteus_ws_client.models.search_parameters import SearchParameters as SearchParameters
from picteus_ws_client.models.search_properties import SearchProperties as SearchProperties
from picteus_ws_client.models.search_property_range import SearchPropertyRange as SearchPropertyRange
from picteus_ws_client.models.search_range import SearchRange as SearchRange
from picteus_ws_client.models.search_repositories_origin import SearchRepositoriesOrigin as SearchRepositoriesOrigin
from picteus_ws_client.models.search_sorting import SearchSorting as SearchSorting
from picteus_ws_client.models.search_sorting_property import SearchSortingProperty as SearchSortingProperty
from picteus_ws_client.models.search_tags import SearchTags as SearchTags
from picteus_ws_client.models.search_tags_result import SearchTagsResult as SearchTagsResult
from picteus_ws_client.models.settings import Settings as Settings
from picteus_ws_client.models.software import Software as Software
from picteus_ws_client.models.textual_prompt import TextualPrompt as TextualPrompt
from picteus_ws_client.models.user_interface_anchor import UserInterfaceAnchor as UserInterfaceAnchor




# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.extension_generation_options import ExtensionGenerationOptions

class TestExtensionGenerationOptions(unittest.TestCase):
    """ExtensionGenerationOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ExtensionGenerationOptions:
        """Test ExtensionGenerationOptions
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ExtensionGenerationOptions`
        """
        model = ExtensionGenerationOptions()
        if include_optional:
            return ExtensionGenerationOptions(
                id = 'extension-id',
                version = '1.0.0',
                name = 'My extension',
                description = 'Computes the embeddings of images.',
                author = 'John Doe',
                environment = 'python'
            )
        else:
            return ExtensionGenerationOptions(
                id = 'extension-id',
                version = '1.0.0',
                name = 'My extension',
                description = 'Computes the embeddings of images.',
                author = 'John Doe',
                environment = 'python',
        )
        """

    def testExtensionGenerationOptions(self):
        """Test ExtensionGenerationOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.search_features import SearchFeatures

class TestSearchFeatures(unittest.TestCase):
    """SearchFeatures unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchFeatures:
        """Test SearchFeatures
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchFeatures`
        """
        model = SearchFeatures()
        if include_optional:
            return SearchFeatures(
                operator = 'or',
                conditions = [
                    picteus_ws_client.models.search_feature_condition.SearchFeatureCondition(
                        type = nature, 
                        format = null, 
                        name = 'field', 
                        operator = null, 
                        value = Three women in a flower arrangement, )
                    ],
                features = picteus_ws_client.models.search_features.SearchFeatures(
                    operator = or, 
                    conditions = [
                        picteus_ws_client.models.search_feature_condition.SearchFeatureCondition(
                            type = nature, 
                            format = null, 
                            name = 'field', 
                            operator = null, 
                            value = Three women in a flower arrangement, )
                        ], 
                    features = null, )
            )
        else:
            return SearchFeatures(
                operator = 'or',
                conditions = [
                    picteus_ws_client.models.search_feature_condition.SearchFeatureCondition(
                        type = nature, 
                        format = null, 
                        name = 'field', 
                        operator = null, 
                        value = Three women in a flower arrangement, )
                    ],
        )
        """

    def testSearchFeatures(self):
        """Test SearchFeatures"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.image_attachment_api import ImageAttachmentApi


class TestImageAttachmentApi(unittest.TestCase):
    """ImageAttachmentApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ImageAttachmentApi()

    def tearDown(self) -> None:
        pass

    def test_imageattachment_create(self) -> None:
        """Test case for imageattachment_create

        Declares an image binary attachment
        """
        pass

    def test_imageattachment_download(self) -> None:
        """Test case for imageattachment_download

        Downloads an image binary attachment
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.12.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.application_metadata_item_value import ApplicationMetadataItemValue

class TestApplicationMetadataItemValue(unittest.TestCase):
    """ApplicationMetadataItemValue unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApplicationMetadataItemValue:
        """Test ApplicationMetadataItemValue
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApplicationMetadataItemValue`
        """
        model = ApplicationMetadataItemValue()
        if include_optional:
            return ApplicationMetadataItemValue(
                schema_version = 1,
                id = '820hh5e0w5rmc0ctgw38b1t4pr',
                url = 'https://api.replicate.com/v1/predictions/820hh5e0w5rmc0ctgw38b1t4pr',
                model_tags = google/gemini-2.5-flash-image:2.5,
                software = 'comfyui',
                input_assets = [fb6af249-1061-48a0-9e47-026d7428d709],
                aspect_ratio = 1.7777,
                prompt = None
            )
        else:
            return ApplicationMetadataItemValue(
                schema_version = 1,
                model_tags = google/gemini-2.5-flash-image:2.5,
                prompt = None,
        )
        """

    def testApplicationMetadataItemValue(self):
        """Test ApplicationMetadataItemValue"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
